@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.101 2005/01/13 12:03:09 davyd Exp $ */
+/* $Id: weather.c,v 1.104 2005/01/25 18:18:08 davyd Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -38,7 +38,6 @@
 
 void
 close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data);
-static gchar* formatWeatherMsg (gchar* msg);
 static gboolean calc_sun (WeatherInfo *info);
 
 /* FIXME: these global variables will cause conflicts when multiple
@@ -53,7 +52,7 @@ static gboolean weather_radar = FALSE;
  * DD:degrees (to 3 digits), MM:minutes, SS:seconds H:hemisphere (NESW)
  * Return value is positive for N,E; negative for S,W.
  */
-gdouble dmsh2rad (const gchar *latlon)
+static gdouble dmsh2rad (const gchar *latlon)
 {
     char *p1, *p2;
     int deg, min, sec, dir;
@@ -141,6 +140,8 @@ WeatherLocation *weather_location_config_read (PanelApplet *applet)
     WeatherLocation *location;
     gchar *untrans_name, *trans_name, *code, *zone, *radar, *coordinates;
     
+    trans_name = NULL;
+
     untrans_name = panel_applet_gconf_get_string(applet, "location0", NULL);
     if (!untrans_name) {
         if ( g_strstr_len ("DEFAULT_LOCATION", 16, _("DEFAULT_LOCATION")) == NULL ) {
@@ -611,7 +612,7 @@ static gdouble t0(time_t date)
 
 
 
-gboolean sun (time_t t, gdouble obsLat, gdouble obsLon,
+static gboolean sun (time_t t, gdouble obsLat, gdouble obsLon,
 	  time_t *rise, time_t *set)
 {
     time_t gm_midn;
@@ -1024,7 +1025,7 @@ const gchar *weather_info_get_sky (WeatherInfo *info)
     if (!info->valid)
         return "-";
     if (info->sky < 0)
-	return "Unknown";
+	return _("Unknown");
     return weather_sky_string(info->sky);
 }
 
@@ -1402,7 +1403,7 @@ static void init_pixbufs (void)
       "stock_weather-cloudy",
       "stock_weather-showers",
       "stock_weather-storm",
-      "stock_weahter-snow",
+      "stock_weather-snow",
       "stock_weather-fog",
       "stock_weather-night-clear",
       "stock_weather-night-few-clouds"
